<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Jens Hyllegaard <jens.hyllegaard@gmail.com>
 * @author soer9648 <soer9648@eucl.dk>
 * @author Jacob Palm <mail@jacobpalm.dk>
 */
$lang['server']                = 'Din MySQL server';
$lang['user']                  = 'MySQL brugernavn';
$lang['password']              = 'Kodeord til ovenstående bruger';
$lang['database']              = 'Database der skal benyttes';
$lang['charset']               = 'Tegnsæt benyttet i database';
$lang['debug']                 = 'Vis yderligere debug output';
$lang['forwardClearPass']      = 'Videregiv bruger adgangskoder i klar tekst til nedenstående SQL statement, i stedet for at benytte passcrypt';
$lang['TablesToLock']          = 'Kommasepareret liste over tabeller der skal låses under skrivning';
$lang['checkPass']             = 'SQL-sætning til at kontrollere kodeord';
$lang['getUserInfo']           = 'SQL-sætning til at hente brugerinformation';
$lang['getGroups']             = 'SQL statement til at bestemme en brugers medlemskab af grupper';
$lang['getUsers']              = 'SQL-sætning til at liste alle brugere';
$lang['addUser']               = 'SQL-sætning til at tilføje en ny bruger';
$lang['addGroup']              = 'SQL-sætning til at tilføje en ny gruppe';
$lang['addUserGroup']          = 'SQL-sætning til at tilføje en bruger til en eksisterende gruppe';
$lang['delGroup']              = 'SQL-sætning til at fjerne en gruppe';
$lang['delUser']               = 'SQL-sætning til at slette en bruger';
$lang['delUserRefs']           = 'SQL-sætning til at fjerne en bruger fra alle grupper';
$lang['updateUser']            = 'SQL-sætning til at opdatere en brugerprofil';
$lang['debug_o_0']             = 'ingen';
$lang['debug_o_1']             = 'kun ved fejl';
$lang['debug_o_2']             = 'alle SQL forespørgsler';
